<?php

require_once get_template_directory() . '/includes/loader.php';

add_action( 'after_setup_theme', 'intervio_setup_theme' );
add_action( 'after_setup_theme', 'intervio_load_default_hooks' );


function intervio_setup_theme() {

	load_theme_textdomain( 'intervio', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );
	add_theme_support('woocommerce');
	add_theme_support('wc-product-gallery-lightbox');

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'editor-styles' );
	add_theme_support( 'post', 'page-attributes' );


	// Set the default content width.
	$GLOBALS['content_width'] = 525;
	
	//Register image sizes
	add_image_size( 'intervio_250x312', 250, 312, true ); //'intervio_250x312 Our Testimonials V1'
	add_image_size( 'intervio_270x220', 270, 220, true ); //'intervio_270x220 Case Studies'
	add_image_size( 'intervio_570x400', 570, 400, true ); //'intervio_570x400 Case Studies V4'
	add_image_size( 'intervio_370x250', 370, 250, true ); //'intervio_370x250 Latest News'
	add_image_size( 'intervio_370x520', 370, 520, true ); //'intervio_370x520 Blog Masonry '
	add_image_size( 'intervio_370x350', 370, 350, true ); //'intervio_370x350 Blog Masonry'
	add_image_size( 'intervio_370x340', 370, 340, true ); //'intervio_370x340 Case Studies V2'
	add_image_size( 'intervio_553x432', 553, 432, true ); //'intervio_553x432 Our Testimonials V2'
	add_image_size( 'intervio_245x250', 245, 250, true ); //'intervio_245x250 Our Team'
	add_image_size( 'intervio_200x160', 200, 160, true ); //'intervio_200x160 Feature Services V2'
	add_image_size( 'intervio_136x143', 136, 143, true ); //'intervio_136x143 Feature Services V3'
	add_image_size( 'intervio_225x215', 225, 215, true ); //'intervio_225x215 Our Services V2'
	add_image_size( 'intervio_140x140', 140, 140, true ); //'intervio_140x140 Our Team V2'
	add_image_size( 'intervio_80x80', 80, 80, true ); //'intervio_80x80 Awards Section V2'
	add_image_size( 'intervio_1170x250', 1170, 250, true ); //'intervio_1170x250 Our Blog'
	add_image_size( 'intervio_105x105', 105, 105, true ); //'intervio_105x105 Our Projects '
	add_image_size( 'intervio_85x85', 85, 85, true ); //'intervio_85x85 Latest Work Widget'
		
	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'main_menu' => esc_html__( 'Main Menu', 'intervio' ),
		'onepage_menu' => esc_html__( 'OnePage Menu', 'intervio' ),
	
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'      => 250,
		'height'     => 250,
		'flex-width' => true,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style();
	add_action( 'admin_init', 'intervio_admin_init', 2000000 );
}

function intervio_gutenberg_editor_palette_styles() {
    add_theme_support( 'editor-color-palette', array(
        array(
            'name' => esc_html__( 'strong yellow', 'intervio' ),
            'slug' => 'strong-yellow',
            'color' => '#f7bd00',
        ),
        array(
            'name' => esc_html__( 'strong white', 'intervio' ),
            'slug' => 'strong-white',
            'color' => '#fff',
        ),
		array(
            'name' => esc_html__( 'light black', 'intervio' ),
            'slug' => 'light-black',
            'color' => '#242424',
        ),
        array(
            'name' => esc_html__( 'very light gray', 'intervio' ),
            'slug' => 'very-light-gray',
            'color' => '#797979',
        ),
        array(
            'name' => esc_html__( 'very dark black', 'intervio' ),
            'slug' => 'very-dark-black',
            'color' => '#000000',
        ),
    ) );
	
	add_theme_support( 'editor-font-sizes', array(
		array(
			'name' => esc_html__( 'Small', 'intervio' ),
			'size' => 10,
			'slug' => 'small'
		),
		array(
			'name' => esc_html__( 'Normal', 'intervio' ),
			'size' => 15,
			'slug' => 'normal'
		),
		array(
			'name' => esc_html__( 'Large', 'intervio' ),
			'size' => 24,
			'slug' => 'large'
		),
		array(
			'name' => esc_html__( 'Huge', 'intervio' ),
			'size' => 36,
			'slug' => 'huge'
		)
	) );
	
}
add_action( 'after_setup_theme', 'intervio_gutenberg_editor_palette_styles' );


/*---------- Enqueue Styles and Scripts ----------*/

function intervio_enqueue_scripts() {
	$options = intervio_WSH()->option();		
		 $maincolor = esc_attr( $options->get( 'theme_color_scheme') );		
	     $maincolor = str_replace( '#', '' , $maincolor );	
		 wp_enqueue_style( 'main-color', get_template_directory_uri() . '/assets/css/color.php?main_color='.$maincolor );

    //styles
	wp_enqueue_style( 'animate', get_template_directory_uri() . '/assets/css/animate.css' );
	
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css' );
	wp_enqueue_style( 'botstrap-select', get_template_directory_uri() . '/assets/css/botstrap-select.min.css' );
	wp_enqueue_style( 'custom-animate', get_template_directory_uri() . '/assets/css/custom-animate.css' );
	wp_enqueue_style( 'flaticon', get_template_directory_uri() . '/assets/css/flaticon.css' );
	wp_enqueue_style( 'fontawesome-all', get_template_directory_uri() . '/assets/css/fontawesome-all.css' );
	wp_enqueue_style( 'hover', get_template_directory_uri() . '/assets/css/hover.css' );
	wp_enqueue_style( 'jquery-fancybox', get_template_directory_uri() . '/assets/css/jquery.fancybox.min.css' );
	wp_enqueue_style( 'jquery-touchspin', get_template_directory_uri() . '/assets/css/jquery.touchspin.css' );
	wp_enqueue_style( 'jquery-ui', get_template_directory_uri() . '/assets/css/jquery-ui.css' );
	wp_enqueue_style( 'line-awesome', get_template_directory_uri() . '/assets/css/line-awesome.css' );
	wp_enqueue_style( 'owl', get_template_directory_uri() . '/assets/css/owl.css' );
	wp_enqueue_style( 'scrollbar', get_template_directory_uri() . '/assets/css/scrollbar.css' );
	wp_enqueue_style( 'swiper', get_template_directory_uri() . '/assets/css/swiper.min.css' );
	wp_enqueue_style( 'datetimepicker', get_template_directory_uri() . '/assets/css/datetimepicker.css' );
	wp_enqueue_style( 'appointment', get_template_directory_uri() . '/assets/css/appointment.css' );
	wp_enqueue_style( 'style-2', get_template_directory_uri() . '/assets/css/style-2.css' );
	
	//Custom CSS
	//
	wp_enqueue_style( 'intervio-gutenberg', get_template_directory_uri() . '/assets/css/theme/gutenberg.css' );
	wp_enqueue_style( 'intervio-error', get_template_directory_uri() . '/assets/css/theme/error.css' );
	wp_enqueue_style( 'intervio-sidebar', get_template_directory_uri() . '/assets/css/theme/sidebar.css' );
	wp_enqueue_style( 'intervio-tut', get_template_directory_uri() . '/assets/css/theme/tut.css' );
	wp_enqueue_style( 'intervio-fixing', get_template_directory_uri() . '/assets/css/theme/fixing.css' );
	wp_enqueue_style( 'intervio-style', get_template_directory_uri() . '/assets/css/style.css' );
	wp_enqueue_style( 'intervio-color-panel', get_template_directory_uri() . '/assets/css/color-panel.css' );
	wp_enqueue_style( 'intervio-rtl', get_template_directory_uri() . '/assets/css/rtl.css' );
	wp_enqueue_style( 'intervio-woocommerce', get_template_directory_uri() . '/assets/css/woocommerce.css' );
	wp_enqueue_style( 'intervio-main-style', get_stylesheet_uri() );	

	wp_enqueue_style( 'intervio-responsive', get_template_directory_uri() . '/assets/css/responsive.css' );
	
	
    //scripts
	wp_enqueue_script( 'jquery-ui-core');
	
	
	wp_enqueue_script( 'appear', get_template_directory_uri().'/assets/js/appear.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'bootstrap', get_template_directory_uri().'/assets/js/bootstrap.min.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'bootstrap-select', get_template_directory_uri().'/assets/js/bootstrap-select.min.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'isotope', get_template_directory_uri().'/assets/js/isotope.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'jquery-bootstrap-touchspin', get_template_directory_uri().'/assets/js/jquery.bootstrap-touchspin.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'jquery-fancybox', get_template_directory_uri().'/assets/js/jquery.fancybox.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'jquery-lettering', get_template_directory_uri().'/assets/js/jquery.lettering.min.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'jquery-ui', get_template_directory_uri().'/assets/js/jquery-ui.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'knob', get_template_directory_uri().'/assets/js/knob.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'language', get_template_directory_uri().'/assets/js/language.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'lazyload', get_template_directory_uri().'/assets/js/lazyload.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'mixitup', get_template_directory_uri().'/assets/js/mixitup.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'owl', get_template_directory_uri().'/assets/js/owl.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'pagenav', get_template_directory_uri().'/assets/js/pagenav.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'popper', get_template_directory_uri().'/assets/js/popper.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'respond', get_template_directory_uri().'/assets/js/respond.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'scrollbar', get_template_directory_uri().'/assets/js/scrollbar.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'swiper', get_template_directory_uri().'/assets/js/swiper.min.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'TweenMax', get_template_directory_uri().'/assets/js/TweenMax.min.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'validate', get_template_directory_uri().'/assets/js/validate.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'wow', get_template_directory_uri().'/assets/js/wow.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'jquery-cookie', get_template_directory_uri().'/assets/js/jquery.cookie.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'themepanel', get_template_directory_uri().'/assets/js/themepanel.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'parallax-scroll', get_template_directory_uri().'/assets/js/parallax-scroll.js', array( 'jquery' ), '2.1.2', true );
	
	wp_enqueue_script( 'main-script', get_template_directory_uri().'/assets/js/script.js', array( 'jquery' ), '2.1.2', true );
	

	if( is_singular() ) wp_enqueue_script('comment-reply');
}
add_action( 'wp_enqueue_scripts', 'intervio_enqueue_scripts' );

/*---------- Enqueue styles and scripts ends ----------*/

/*---------- Google fonts ----------*/

function intervio_fonts_url() {
	
	$fonts_url = '';

		$font_families['Poppins']      = 'Barlow:300,400,500,600,700';
		$font_families['Josfin']      = 'Fira Sans:300,400,500,600,700,800,900';

		$font_families = apply_filters( 'REXAR/includes/classes/header_enqueue/font_families', $font_families );

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$protocol  = is_ssl() ? 'https' : 'http';
		$fonts_url = add_query_arg( $query_args, $protocol . '://fonts.googleapis.com/css' );

		return esc_url_raw($fonts_url);

}

function intervio_theme_styles() {
    wp_enqueue_style( 'intervio-theme-fonts', intervio_fonts_url(), array(), null );
}

add_action( 'wp_enqueue_scripts', 'intervio_theme_styles' );
add_action( 'admin_enqueue_scripts', 'intervio_theme_styles' );

/*---------- Google fonts ends ----------*/

/**
 * [intervio_widgets_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
function intervio_widgets_init() {

	global $wp_registered_sidebars;

	$theme_options = get_theme_mod( INTERVIO_NAME . '_options-mods' );
	$options = intervio_WSH()->option();
	$footer_column_settings   = $options->get( 'footer_column_settings' );
    $allowed_html = wp_kses_allowed_html( 'post' );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Default Sidebar', 'intervio' ),
		'id'            => 'default-sidebar',
		'description'   => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'intervio' ),
		'before_widget' => '<div id="%1$s" class="mrsidebar widget sidebar-widget single-sidebar %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	) );
	register_sidebar(array(
		'name' => esc_html__('Footer Widget', 'intervio'),
		'id' => 'footer-sidebar',
		'description' => esc_html__('Widgets in this area will be shown in Footer Area.', 'intervio'),
		'before_widget'=>'<div class="mrfooter footer-column col-lg-'.$footer_column_settings.' col-md-4 col-sm-12"><div id="%1$s" class="mrfooter footer-widget %2$s">',
		'after_widget'=>'</div></div>',
		'before_title' => '<div class="widget-title"><h3>',
		'after_title' => '</h3><div class="decor" style="background-image: url('.get_template_directory_uri().'/assets/images/icons/decor-3.png);"></div></div>'
	));
	if ( class_exists( '\Elementor\Plugin' )){
	

	register_sidebar(array(
		'name' => esc_html__('Services Widget', 'intervio'),
		'id' => 'service-sidebar',
		'description' => esc_html__('Widgets in this area will be shown in Services Area.', 'intervio'),
		'before_widget'=>'<div id="%1$s" class="service-widget %2$s">',
		'after_widget'=>'</div>',
		'before_title' => '<div class="widget-title"><h3>',
		'after_title' => '</h3></div>'
	));
	}
	register_sidebar(array(
	  'name' => esc_html__( 'Blog Listing', 'intervio' ),
	  'id' => 'blog-sidebar',
	'description'   => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'intervio' ),
		'before_widget' => '<div id="%1$s" class="mrsidebar widget sidebar-widget single-sidebar %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	));
	register_sidebar(array(
	  'name' => esc_html__( 'Menu Hidden Sidebar', 'intervio' ),
	  'id' => 'menu-sidebar',
	  'description' => esc_html__( 'Widgets in this area will be shown on the Menu Hidden Area', 'intervio' ),
	  'before_widget'=>'<div id="%1$s" class="hiddenbar widget sidebar-widget %2$s">',
	  'after_widget'=>'</div>',
	  'before_title' => '<div class="sibedwidget-title"><h4>',
	  'after_title' => '</h4></div>'
	));
	
	if ( ! is_object( intervio_WSH() ) ) {
		return;
	}

	$sidebars = intervio_set( $theme_options, 'custom_sidebar_name' );

	foreach ( array_filter( (array) $sidebars ) as $sidebar ) {

		if ( intervio_set( $sidebar, 'topcopy' ) ) {
			continue;
		}

		$name = $sidebar;
		if ( ! $name ) {
			continue;
		}
		$slug = str_replace( ' ', '_', $name );

		register_sidebar( array(
			'name'          => $name,
			'id'            => sanitize_title( $slug ),
			'before_widget' => '<div id="%1$s" class="%2$s widget ">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="widget-title"><h3>',
			'after_title'   => '</h3></div>',
		) );
	}

	update_option( 'wp_registered_sidebars', $wp_registered_sidebars );
}

add_action( 'widgets_init', 'intervio_widgets_init' );

/**
 * [intervio_admin_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */


function intervio_admin_init() {
	remove_action( 'admin_notices', array( 'ReduxFramework', '_admin_notices' ), 99 );
}

/**
 * [intervio_set description]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
if ( ! function_exists( 'intervio_set' ) ) {
	function intervio_set( $var, $key, $def = '' ) {
		//if( ! $var ) return false;

		if ( is_object( $var ) && isset( $var->$key ) ) {
			return $var->$key;
		} elseif ( is_array( $var ) && isset( $var[ $key ] ) ) {
			return $var[ $key ];
		} elseif ( $def ) {
			return $def;
		} else {
			return false;
		}
	}
}
function intervio_add_editor_styles() {
    add_editor_style( 'editor-style.css' );
}
add_action( 'admin_init', 'intervio_add_editor_styles' );

// Add specific CSS class by filter.
$options = intervio_WSH()->option(); 
if( intervio_set($options, 'boxed_wrapper') ){

add_filter( 'body_class', function( $classes ) {
    $classes[] = 'boxed_wrapper';
    return $classes;
} );
}

/**
 * product per page
 */
add_filter( 'loop_shop_per_page', 'intervio_loop_shop_per_page', 20 );

function intervio_loop_shop_per_page( $cols ) {
		$options     = intervio_WSH()->option();		
		$shop_product = esc_attr( $options->get( 'shop_product') );	
		
  // $cols contains the current number of products per page based on the value stored on Options –> Reading
  // Return the number of products you wanna show per page.
  $cols =  $shop_product;
  return $cols;
}